==> haskell-exact-pi-0.5.0.2-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-18GjPT0hvgx24hvm5uBTYN
key:                  exact-pi-0.5.0.2-18GjPT0hvgx24hvm5uBTYN
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  f6b1db136c9c10cb5ae083f55df50094
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-18GjPT0hvgx24hvm5uBTYN
depends:
    base-4.17.2.1 numtype-dk-0.5.0.3-F6qEUKEaZatXZetkjwDdM

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exact-pi-0.5.0.2-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 exact-pi
version:              0.5.0.2
visibility:           public
id:                   exact-pi-0.5.0.2-3xLUzlkqa6Oc10JVyngD3
key:                  exact-pi-0.5.0.2-3xLUzlkqa6Oc10JVyngD3
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  ffe42da6aae1ff2644931dae088730b0
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/exact-pi-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-exact-pi
hs-libraries:         HSexact-pi-0.5.0.2-3xLUzlkqa6Oc10JVyngD3
depends:
    base-4.17.2.1 numtype-dk-0.5.0.3-F6qEUKEaZatXZetkjwDdM

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
